@@ -26,7 +26,7 @@
  *  writing directory to "C:\MyGame\MyWritingDirectory", then no PHYSFS calls
  *  could touch anything above this directory, including the "C:\MyGame" and
  *  "C:\" directories. This prevents an application's internal scripting
- *  language from piddling over c:\config.sys, for example. If you'd rather
+ *  language from piddling over c:\\config.sys, for example. If you'd rather
  *  give PHYSFS full access to the system's REAL file system, set the writing
  *  dir to "C:\", but that's generally A Bad Thing for several reasons.
  *
@@ -61,20 +61,21 @@
  * Once the search path is defined, you may open files for reading. If you've
  *  got the following search path defined (to use a win32 example again):
  *
- *    C:\mygame
- *    C:\mygame\myuserfiles
- *    D:\mygamescdromdatafiles
- *    C:\mygame\installeddatafiles.zip
+ *  - C:\\mygame
+ *  - C:\\mygame\\myuserfiles
+ *  - D:\\mygamescdromdatafiles
+ *  - C:\\mygame\\installeddatafiles.zip
  *
  * Then a call to PHYSFS_openRead("textfiles/myfile.txt") (note the directory
  *  separator, lack of drive letter, and lack of dir separator at the start of
  *  the string; this is platform-independent notation) will check for
- *  C:\mygame\textfiles\myfile.txt, then
- *  C:\mygame\myuserfiles\textfiles\myfile.txt, then
- *  D:\mygamescdromdatafiles\textfiles\myfile.txt, then, finally, for
- *  textfiles\myfile.txt inside of C:\mygame\installeddatafiles.zip. Remember
- *  that most archive types and platform filesystems store their filenames in
- *  a case-sensitive manner, so you should be careful to specify it correctly.
+ *  C:\\mygame\\textfiles\\myfile.txt, then
+ *  C:\\mygame\\myuserfiles\\textfiles\\myfile.txt, then
+ *  D:\\mygamescdromdatafiles\\textfiles\\myfile.txt, then, finally, for
+ *  textfiles\\myfile.txt inside of C:\\mygame\\installeddatafiles.zip.
+ *  Remember that most archive types and platform filesystems store their
+ *  filenames in a case-sensitive manner, so you should be careful to specify
+ *  it correctly.
  *
  * Files opened through PhysicsFS may NOT contain "." or ".." or ":" as dir
  *  elements. Not only are these meaningless on MacOS and/or Unix, they are a
@@ -131,6 +132,7 @@
  *   - .PAK (Quake I/II archive format)
  *   - .HOG (Descent I/II HOG file archives)
  *   - .MVL (Descent II movielib archives)
+ *   - .WAD (DOOM engine archives)
  *
  * Please see the file LICENSE in the source's root directory for licensing
  *  and redistribution rights.
@@ -267,8 +269,9 @@ PHYSFS_COMPILE_TIME_ASSERT(sint64, sizeof(PHYSFS_sint64) == 8);
 typedef struct
 {
     void *opaque;  /**< That's all you get. Don't touch. */
-} PHYSFS_file;
+} PHYSFS_File;
 
+typedef PHYSFS_File PHYSFS_file;  /* for backwards compatibility with 1.0 */
 
 
 /**
@@ -316,9 +319,9 @@ typedef struct
 } PHYSFS_Version;
 
 #ifndef DOXYGEN_SHOULD_IGNORE_THIS
-#define PHYSFS_VER_MAJOR 0
-#define PHYSFS_VER_MINOR 1
-#define PHYSFS_VER_PATCH 9
+#define PHYSFS_VER_MAJOR 1
+#define PHYSFS_VER_MINOR 0
+#define PHYSFS_VER_PATCH 1
 #endif  /* DOXYGEN_SHOULD_IGNORE_THIS */
 
 
@@ -853,8 +856,8 @@ __EXPORT__ int PHYSFS_delete(const char *filename);
  *  matches in different parts of the search path, only the first one found
  *  is used, just like when opening a file.
  *
- * So, if you look for "maps/level1.map", and C:\mygame is in your search
- *  path and C:\mygame\maps\level1.map exists, then "C:\mygame" is returned.
+ * So, if you look for "maps/level1.map", and C:\\mygame is in your search
+ *  path and C:\\mygame\\maps\\level1.map exists, then "C:\mygame" is returned.
  *
  * If a any part of a match is a symbolic link, and you've not explicitly
  *  permitted symlinks, then it will be ignored, and the search for a match
@@ -1429,7 +1432,7 @@ __EXPORT__ PHYSFS_uint64 PHYSFS_swapUBE64(PHYSFS_uint64 val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_readSLE16(PHYSFS_file *file, PHYSFS_sint16 *val);
 
@@ -1445,7 +1448,7 @@ __EXPORT__ int PHYSFS_readSLE16(PHYSFS_file *file, PHYSFS_sint16 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  *
  */
 __EXPORT__ int PHYSFS_readULE16(PHYSFS_file *file, PHYSFS_uint16 *val);
@@ -1462,7 +1465,7 @@ __EXPORT__ int PHYSFS_readULE16(PHYSFS_file *file, PHYSFS_uint16 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_readSBE16(PHYSFS_file *file, PHYSFS_sint16 *val);
 
@@ -1478,7 +1481,7 @@ __EXPORT__ int PHYSFS_readSBE16(PHYSFS_file *file, PHYSFS_sint16 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  *
  */
 __EXPORT__ int PHYSFS_readUBE16(PHYSFS_file *file, PHYSFS_uint16 *val);
@@ -1495,7 +1498,7 @@ __EXPORT__ int PHYSFS_readUBE16(PHYSFS_file *file, PHYSFS_uint16 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_readSLE32(PHYSFS_file *file, PHYSFS_sint32 *val);
 
@@ -1511,7 +1514,7 @@ __EXPORT__ int PHYSFS_readSLE32(PHYSFS_file *file, PHYSFS_sint32 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  *
  */
 __EXPORT__ int PHYSFS_readULE32(PHYSFS_file *file, PHYSFS_uint32 *val);
@@ -1528,7 +1531,7 @@ __EXPORT__ int PHYSFS_readULE32(PHYSFS_file *file, PHYSFS_uint32 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_readSBE32(PHYSFS_file *file, PHYSFS_sint32 *val);
 
@@ -1544,7 +1547,7 @@ __EXPORT__ int PHYSFS_readSBE32(PHYSFS_file *file, PHYSFS_sint32 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  *
  */
 __EXPORT__ int PHYSFS_readUBE32(PHYSFS_file *file, PHYSFS_uint32 *val);
@@ -1561,7 +1564,7 @@ __EXPORT__ int PHYSFS_readUBE32(PHYSFS_file *file, PHYSFS_uint32 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  *
  * \warning Remember, PHYSFS_sint64 is only 32 bits on platforms without
  *          any sort of 64-bit support.
@@ -1580,7 +1583,7 @@ __EXPORT__ int PHYSFS_readSLE64(PHYSFS_file *file, PHYSFS_sint64 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  *
  * \warning Remember, PHYSFS_uint64 is only 32 bits on platforms without
  *          any sort of 64-bit support.
@@ -1599,7 +1602,7 @@ __EXPORT__ int PHYSFS_readULE64(PHYSFS_file *file, PHYSFS_uint64 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  *
  * \warning Remember, PHYSFS_sint64 is only 32 bits on platforms without
  *          any sort of 64-bit support.
@@ -1618,7 +1621,7 @@ __EXPORT__ int PHYSFS_readSBE64(PHYSFS_file *file, PHYSFS_sint64 *val);
  *    \param val pointer to where value should be stored.
  *   \return zero on failure, non-zero on success. If successful, (*val) will
  *           store the result. On failure, you can find out what went wrong
- *           from PHYSFS_GetLastError().
+ *           from PHYSFS_getLastError().
  *
  * \warning Remember, PHYSFS_uint64 is only 32 bits on platforms without
  *          any sort of 64-bit support.
@@ -1636,7 +1639,7 @@ __EXPORT__ int PHYSFS_readUBE64(PHYSFS_file *file, PHYSFS_uint64 *val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_writeSLE16(PHYSFS_file *file, PHYSFS_sint16 val);
 
@@ -1651,7 +1654,7 @@ __EXPORT__ int PHYSFS_writeSLE16(PHYSFS_file *file, PHYSFS_sint16 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_writeULE16(PHYSFS_file *file, PHYSFS_uint16 val);
 
@@ -1666,7 +1669,7 @@ __EXPORT__ int PHYSFS_writeULE16(PHYSFS_file *file, PHYSFS_uint16 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_writeSBE16(PHYSFS_file *file, PHYSFS_sint16 val);
 
@@ -1681,7 +1684,7 @@ __EXPORT__ int PHYSFS_writeSBE16(PHYSFS_file *file, PHYSFS_sint16 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_writeUBE16(PHYSFS_file *file, PHYSFS_uint16 val);
 
@@ -1696,7 +1699,7 @@ __EXPORT__ int PHYSFS_writeUBE16(PHYSFS_file *file, PHYSFS_uint16 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_writeSLE32(PHYSFS_file *file, PHYSFS_sint32 val);
 
@@ -1711,7 +1714,7 @@ __EXPORT__ int PHYSFS_writeSLE32(PHYSFS_file *file, PHYSFS_sint32 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_writeULE32(PHYSFS_file *file, PHYSFS_uint32 val);
 
@@ -1726,7 +1729,7 @@ __EXPORT__ int PHYSFS_writeULE32(PHYSFS_file *file, PHYSFS_uint32 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_writeSBE32(PHYSFS_file *file, PHYSFS_sint32 val);
 
@@ -1741,7 +1744,7 @@ __EXPORT__ int PHYSFS_writeSBE32(PHYSFS_file *file, PHYSFS_sint32 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  */
 __EXPORT__ int PHYSFS_writeUBE32(PHYSFS_file *file, PHYSFS_uint32 val);
 
@@ -1756,7 +1759,7 @@ __EXPORT__ int PHYSFS_writeUBE32(PHYSFS_file *file, PHYSFS_uint32 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  *
  * \warning Remember, PHYSFS_uint64 is only 32 bits on platforms without
  *          any sort of 64-bit support.
@@ -1774,7 +1777,7 @@ __EXPORT__ int PHYSFS_writeSLE64(PHYSFS_file *file, PHYSFS_sint64 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  *
  * \warning Remember, PHYSFS_uint64 is only 32 bits on platforms without
  *          any sort of 64-bit support.
@@ -1792,7 +1795,7 @@ __EXPORT__ int PHYSFS_writeULE64(PHYSFS_file *file, PHYSFS_uint64 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  *
  * \warning Remember, PHYSFS_uint64 is only 32 bits on platforms without
  *          any sort of 64-bit support.
@@ -1810,7 +1813,7 @@ __EXPORT__ int PHYSFS_writeSBE64(PHYSFS_file *file, PHYSFS_sint64 val);
  *    \param file PhysicsFS file handle to which to write.
  *    \param val Value to convert and write.
  *   \return zero on failure, non-zero on success. On failure, you can
- *           find out what went wrong from PHYSFS_GetLastError().
+ *           find out what went wrong from PHYSFS_getLastError().
  *
  * \warning Remember, PHYSFS_uint64 is only 32 bits on platforms without
  *          any sort of 64-bit support.
