@@ -18,7 +18,7 @@
 
 #ifdef HAVE_ASSERT_H
 #include <assert.h>
-#else
+#elif (!defined assert)
 #define assert(x)
 #endif
 
@@ -39,9 +39,10 @@ extern "C" {
 #define PHYSFS_LANG_RUSSIAN_CP1251     3  /* Russian by Ed Sinjiashvili */
 #define PHYSFS_LANG_RUSSIAN_CP866      4  /* Russian by Ed Sinjiashvili */
 #define PHYSFS_LANG_RUSSIAN_ISO_8859_5 5  /* Russian by Ed Sinjiashvili */
-/* need spanish. */
+#define PHYSFS_LANG_SPANISH            6  /* Spanish by Pedro J. Prez  */
 #define PHYSFS_LANG_FRENCH             7  /*  French by Stphane Peter  */
 #define PHYSFS_LANG_GERMAN             8  /*  German by Michael Renner  */
+#define PHYSFS_LANG_PORTUGUESE_BR      9  /* pt-br by Danny Angelo Carminati Grein  */
 
 #if (PHYSFS_LANG == PHYSFS_LANG_ENGLISH)
  #define DIR_ARCHIVE_DESCRIPTION  "Non-archive, direct filesystem I/O"
@@ -50,6 +51,7 @@ extern "C" {
  #define MVL_ARCHIVE_DESCRIPTION  "Descent II Movielib format"
  #define QPAK_ARCHIVE_DESCRIPTION "Quake I/II format"
  #define ZIP_ARCHIVE_DESCRIPTION  "PkZip/WinZip/Info-Zip compatible"
+ #define WAD_ARCHIVE_DESCRIPTION  "DOOM engine format"
 
  #define ERR_IS_INITIALIZED       "Already initialized"
  #define ERR_NOT_INITIALIZED      "Not initialized"
@@ -147,6 +149,7 @@ extern "C" {
  #define MVL_ARCHIVE_DESCRIPTION  "Descent II Movielib format"
  #define QPAK_ARCHIVE_DESCRIPTION "Quake I/II format"
  #define ZIP_ARCHIVE_DESCRIPTION  "PkZip/WinZip/Info-Zip kompatibel"
+ #define WAD_ARCHIVE_DESCRIPTION  "DOOM engine format"
 
  #define ERR_IS_INITIALIZED       "Bereits initialisiert"
  #define ERR_NOT_INITIALIZED      "Nicht initialisiert"
@@ -243,6 +246,7 @@ extern "C" {
  #define HOG_ARCHIVE_DESCRIPTION  "Descent I/II HOG file format"
  #define MVL_ARCHIVE_DESCRIPTION  "Descent II Movielib format"
  #define ZIP_ARCHIVE_DESCRIPTION  "PkZip/WinZip/Info-Zip "
+ #define WAD_ARCHIVE_DESCRIPTION  "DOOM engine format" // !!! FIXME: translate this line if needed
 
  #define ERR_IS_INITIALIZED       " "
  #define ERR_NOT_INITIALIZED      " "
@@ -339,6 +343,7 @@ extern "C" {
  #define HOG_ARCHIVE_DESCRIPTION  "Descent I/II HOG file format"
  #define MVL_ARCHIVE_DESCRIPTION  "Descent II Movielib format"
  #define ZIP_ARCHIVE_DESCRIPTION  "PkZip/WinZip/Info-Zip "
+ #define WAD_ARCHIVE_DESCRIPTION  "DOOM engine format" // FIXME: translate this line if needed
 
  #define ERR_IS_INITIALIZED       " "
  #define ERR_NOT_INITIALIZED      " "
@@ -435,6 +440,7 @@ extern "C" {
  #define HOG_ARCHIVE_DESCRIPTION  "Descent I/II HOG file format"
  #define MVL_ARCHIVE_DESCRIPTION  "Descent II Movielib format"
  #define ZIP_ARCHIVE_DESCRIPTION  "PkZip/WinZip/Info-Zip ᮢ⨬"
+ #define WAD_ARCHIVE_DESCRIPTION  "DOOM engine format" // FIXME: Translate this line if needed
 
  #define ERR_IS_INITIALIZED       " 樠஢"
  #define ERR_NOT_INITIALIZED      " 樠஢"
@@ -531,6 +537,7 @@ extern "C" {
  #define HOG_ARCHIVE_DESCRIPTION  "Descent I/II HOG file format"
  #define MVL_ARCHIVE_DESCRIPTION  "Descent II Movielib format"
  #define ZIP_ARCHIVE_DESCRIPTION  "PkZip/WinZip/Info-Zip "
+ #define WAD_ARCHIVE_DESCRIPTION  "DOOM engine format"  // FIXME: translate this line if needed
 
  #define ERR_IS_INITIALIZED       " "
  #define ERR_NOT_INITIALIZED      " "
@@ -629,6 +636,7 @@ extern "C" {
  #define MVL_ARCHIVE_DESCRIPTION  "Descent II Movielib format"
  #define QPAK_ARCHIVE_DESCRIPTION "Quake I/II format"
  #define ZIP_ARCHIVE_DESCRIPTION  "Compatible PkZip/WinZip/Info-Zip"
+ #define WAD_ARCHIVE_DESCRIPTION  "Format WAD du moteur DOOM"
 
  #define ERR_IS_INITIALIZED       "Dj initialis"
  #define ERR_NOT_INITIALIZED      "Non initialis"
@@ -719,6 +727,201 @@ extern "C" {
  #define ERR_PROT_VIOLATION       "Violation de protection"
  #define ERR_BROKEN_PIPE          "Tube cass"
 
+#elif (PHYSFS_LANG == PHYSFS_LANG_PORTUGUESE_BR)
+ #define DIR_ARCHIVE_DESCRIPTION  "No arquivo, E/S sistema de arquivos direto"
+ #define GRP_ARCHIVE_DESCRIPTION  "Formato Groupfile do engine Build"
+ #define HOG_ARCHIVE_DESCRIPTION  "Formato Descent I/II HOG file"
+ #define MVL_ARCHIVE_DESCRIPTION  "Formato Descent II Movielib"
+ #define QPAK_ARCHIVE_DESCRIPTION "Formato Quake I/II"
+ #define ZIP_ARCHIVE_DESCRIPTION  "Formato compatvel PkZip/WinZip/Info-Zip"
+ #define WAD_ARCHIVE_DESCRIPTION  "Formato WAD do engine DOOM"
+
+ #define ERR_IS_INITIALIZED       "J inicializado"
+ #define ERR_NOT_INITIALIZED      "No inicializado"
+ #define ERR_INVALID_ARGUMENT     "Argumento invlido"
+ #define ERR_FILES_STILL_OPEN     "Arquivos ainda abertos"
+ #define ERR_NO_DIR_CREATE        "Falha na criao de diretrios"
+ #define ERR_OUT_OF_MEMORY        "Memria insuficiente"
+ #define ERR_NOT_IN_SEARCH_PATH   "Entrada no encontrada no caminho de busca"
+ #define ERR_NOT_SUPPORTED        "Operao no suportada"
+ #define ERR_UNSUPPORTED_ARCHIVE  "Tipo de arquivo no suportado"
+ #define ERR_NOT_A_HANDLE         "No  um handler de arquivo"
+ #define ERR_INSECURE_FNAME       "Nome de arquivo inseguro"
+ #define ERR_SYMLINK_DISALLOWED   "Links simblicos desabilitados"
+ #define ERR_NO_WRITE_DIR         "Diretrio de escrita no definido"
+ #define ERR_NO_SUCH_FILE         "Arquivo no encontrado"
+ #define ERR_NO_SUCH_PATH         "Caminho no encontrado"
+ #define ERR_NO_SUCH_VOLUME       "Volume no encontrado"
+ #define ERR_PAST_EOF             "Passou o fim do arquivo"
+ #define ERR_ARC_IS_READ_ONLY     "Arquivo  somente de leitura"
+ #define ERR_IO_ERROR             "Erro de E/S"
+ #define ERR_CANT_SET_WRITE_DIR   "No foi possvel definir diretrio de escrita"
+ #define ERR_SYMLINK_LOOP         "Loop infinito de link simblico"
+ #define ERR_COMPRESSION          "Erro de (Des)compresso"
+ #define ERR_NOT_IMPLEMENTED      "No implementado"
+ #define ERR_OS_ERROR             "Erro reportado pelo Sistema Operacional"
+ #define ERR_FILE_EXISTS          "Arquivo j existente"
+ #define ERR_NOT_A_FILE           "No  um arquivo"
+ #define ERR_NOT_A_DIR            "No  um diretrio"
+ #define ERR_NOT_AN_ARCHIVE       "No  um pacote"
+ #define ERR_CORRUPTED            "Pacote corrompido"
+ #define ERR_SEEK_OUT_OF_RANGE    "Posicionamento alm do tamanho"
+ #define ERR_BAD_FILENAME         "Nome de arquivo invlido"
+ #define ERR_PHYSFS_BAD_OS_CALL   "(BUG) PhysicsFS realizou uma chamada de sistema invlida"
+ #define ERR_ARGV0_IS_NULL        "argv0  NULL"
+ #define ERR_ZLIB_NEED_DICT       "zlib: precisa de diretrio"
+ #define ERR_ZLIB_DATA_ERROR      "zlib: erro nos dados"
+ #define ERR_ZLIB_MEMORY_ERROR    "zlib: erro de memria"
+ #define ERR_ZLIB_BUFFER_ERROR    "zlib: erro de buffer"
+ #define ERR_ZLIB_VERSION_ERROR   "zlib: erro na version"
+ #define ERR_ZLIB_UNKNOWN_ERROR   "zlib: erro desconhecido"
+ #define ERR_SEARCHPATH_TRUNC     "Caminho de procura quebrado"
+ #define ERR_GETMODFN_TRUNC       "GetModuleFileName() foi quebrado"
+ #define ERR_GETMODFN_NO_DIR      "GetModuleFileName() nao teve diretrio"
+ #define ERR_DISK_FULL            "Disco cheio"
+ #define ERR_DIRECTORY_FULL       "Diretrio cheio"
+ #define ERR_MACOS_GENERIC        "MacOS reportou um erro (%d)"
+ #define ERR_OS2_GENERIC          "OS/2 reportou um erro (%d)"
+ #define ERR_VOL_LOCKED_HW        "Volume travado por hardware"
+ #define ERR_VOL_LOCKED_SW        "Volume travado por software"
+ #define ERR_FILE_LOCKED          "Arquivo travado"
+ #define ERR_FILE_OR_DIR_BUSY     "Arquivo/Diretrio est em uso"
+ #define ERR_FILE_ALREADY_OPEN_W  "Arquivo j aberto para escrita"
+ #define ERR_FILE_ALREADY_OPEN_R  "Arquivo j aberto para leitura"
+ #define ERR_INVALID_REFNUM       "Nmero de referncia"
+ #define ERR_GETTING_FILE_POS     "Erro ao tentar obter posio do arquivo"
+ #define ERR_VOLUME_OFFLINE       "Volume est indisponvel"
+ #define ERR_PERMISSION_DENIED    "Permisso negada"
+ #define ERR_VOL_ALREADY_ONLINE   "Volume disponvel"
+ #define ERR_NO_SUCH_DRIVE        "Drive inexistente"
+ #define ERR_NOT_MAC_DISK         "No  um disco Macintosh"
+ #define ERR_VOL_EXTERNAL_FS      "Volume pertence a um sistema de arquivos externo"
+ #define ERR_PROBLEM_RENAME       "Problema durante renomeao"
+ #define ERR_BAD_MASTER_BLOCK     "Bloco master do diretrio invlido"
+ #define ERR_CANT_MOVE_FORBIDDEN  "Tentativa de mover proibida"
+ #define ERR_WRONG_VOL_TYPE       "Tipo invlido de volume"
+ #define ERR_SERVER_VOL_LOST      "Volume servidor desconectado"
+ #define ERR_FILE_ID_NOT_FOUND    "ID de Arquivo no encontrado"
+ #define ERR_FILE_ID_EXISTS       "ID de Arquivo j existente"
+ #define ERR_SERVER_NO_RESPOND    "Servidor no respondendo"
+ #define ERR_USER_AUTH_FAILED     "Autenticao de usurio falhada"
+ #define ERR_PWORD_EXPIRED        "Password foi expirada no servidor"
+ #define ERR_ACCESS_DENIED        "Accesso negado"
+ #define ERR_NOT_A_DOS_DISK       "No  um disco DOS"
+ #define ERR_SHARING_VIOLATION    "Violao de compartilhamento"
+ #define ERR_CANNOT_MAKE          "No pode ser feito"
+ #define ERR_DEV_IN_USE           "Device j em uso"
+ #define ERR_OPEN_FAILED          "Falaha na abertura"
+ #define ERR_PIPE_BUSY            "Fila ocupada"
+ #define ERR_SHARING_BUF_EXCEEDED "Buffer de compartilhamento excedeu"
+ #define ERR_TOO_MANY_HANDLES     "Muitos handles abertos"
+ #define ERR_SEEK_ERROR           "Erro de posicionamento"
+ #define ERR_DEL_CWD              "Tentando remover diretrio de trabalho atual"
+ #define ERR_WRITE_PROTECT_ERROR  "Erro de proteo de escrita"
+ #define ERR_WRITE_FAULT          "Erro de escrita"
+ #define ERR_LOCK_VIOLATION       "Violao de trava"
+ #define ERR_GEN_FAILURE          "Falha geral"
+ #define ERR_UNCERTAIN_MEDIA      "Media incerta"
+ #define ERR_PROT_VIOLATION       "Violao de proteo"
+ #define ERR_BROKEN_PIPE          "Fila quebrada"
+
+#elif (PHYSFS_LANG == PHYSFS_LANG_SPANISH)
+ #define DIR_ARCHIVE_DESCRIPTION  "No es un archivo, E/S directa al sistema de ficheros"
+ #define GRP_ARCHIVE_DESCRIPTION  "Formato Build engine Groupfile"
+ #define HOG_ARCHIVE_DESCRIPTION  "Formato Descent I/II HOG file"
+ #define MVL_ARCHIVE_DESCRIPTION  "Formato Descent II Movielib"
+ #define QPAK_ARCHIVE_DESCRIPTION "Formato Quake I/II"
+ #define ZIP_ARCHIVE_DESCRIPTION  "Compatible con PkZip/WinZip/Info-Zip"
+
+ #define ERR_IS_INITIALIZED       "Ya estaba inicializado"
+ #define ERR_NOT_INITIALIZED      "No est inicializado"
+ #define ERR_INVALID_ARGUMENT     "Argumento invlido"
+ #define ERR_FILES_STILL_OPEN     "Archivos an abiertos"
+ #define ERR_NO_DIR_CREATE        "Fallo al crear los directorios"
+ #define ERR_OUT_OF_MEMORY        "Memoria agotada"
+ #define ERR_NOT_IN_SEARCH_PATH   "No existe tal entrada en la ruta de bsqueda"
+ #define ERR_NOT_SUPPORTED        "Operacin no soportada"
+ #define ERR_UNSUPPORTED_ARCHIVE  "Tipo de archivo no soportado"
+ #define ERR_NOT_A_HANDLE         "No es un manejador de ficheo (file handle)"
+ #define ERR_INSECURE_FNAME       "Nombre de archivo inseguro"
+ #define ERR_SYMLINK_DISALLOWED   "Los enlaces simblicos estn desactivados"
+ #define ERR_NO_WRITE_DIR         "No has configurado un directorio de escritura"
+ #define ERR_NO_SUCH_FILE         "Archivo no encontrado"
+ #define ERR_NO_SUCH_PATH         "Ruta no encontrada"
+ #define ERR_NO_SUCH_VOLUME       "Volumen no encontrado"
+ #define ERR_PAST_EOF             "Te pasaste del final del archivo"
+ #define ERR_ARC_IS_READ_ONLY     "El archivo es de slo lectura"
+ #define ERR_IO_ERROR             "Error E/S"
+ #define ERR_CANT_SET_WRITE_DIR   "No puedo configurar el directorio de escritura"
+ #define ERR_SYMLINK_LOOP         "Bucle infnito de enlaces simblicos"
+ #define ERR_COMPRESSION          "Error de (des)compresin"
+ #define ERR_NOT_IMPLEMENTED      "No implementado"
+ #define ERR_OS_ERROR             "El sistema operativo ha devuelto un error"
+ #define ERR_FILE_EXISTS          "El archivo ya existe"
+ #define ERR_NOT_A_FILE           "No es un archivo"
+ #define ERR_NOT_A_DIR            "No es un directorio"
+ #define ERR_NOT_AN_ARCHIVE       "No es un archivo"
+ #define ERR_CORRUPTED            "Archivo corrupto"
+ #define ERR_SEEK_OUT_OF_RANGE    "Bsqueda fuera de rango"
+ #define ERR_BAD_FILENAME         "Nombre de archivo incorrecto"
+ #define ERR_PHYSFS_BAD_OS_CALL   "(BUG) PhysicsFS ha hecho una llamada incorrecta al sistema"
+ #define ERR_ARGV0_IS_NULL        "argv0 es NULL"
+ #define ERR_ZLIB_NEED_DICT       "zlib: necesito diccionario"
+ #define ERR_ZLIB_DATA_ERROR      "zlib: error de datos"
+ #define ERR_ZLIB_MEMORY_ERROR    "zlib: error de memoria"
+ #define ERR_ZLIB_BUFFER_ERROR    "zlib: error de buffer"
+ #define ERR_ZLIB_VERSION_ERROR   "zlib: error de versin"
+ #define ERR_ZLIB_UNKNOWN_ERROR   "zlib: error desconocido"
+ #define ERR_SEARCHPATH_TRUNC     "La ruta de bsqueda ha sido truncada"
+ #define ERR_GETMODFN_TRUNC       "GetModuleFileName() ha sido truncado"
+ #define ERR_GETMODFN_NO_DIR      "GetModuleFileName() no tenia directorio"
+ #define ERR_DISK_FULL            "El disco est lleno"
+ #define ERR_DIRECTORY_FULL       "El directorio est lleno"
+ #define ERR_MACOS_GENERIC        "MacOS ha devuelto un error (%d)"
+ #define ERR_OS2_GENERIC          "OS/2 ha devuelto un error (%d)"
+ #define ERR_VOL_LOCKED_HW        "El volumen est bloqueado por el hardware"
+ #define ERR_VOL_LOCKED_SW        "El volumen est bloqueado por el software"
+ #define ERR_FILE_LOCKED          "El archivo est bloqueado"
+ #define ERR_FILE_OR_DIR_BUSY     "Fichero o directorio ocupados"
+ #define ERR_FILE_ALREADY_OPEN_W  "Fichero ya abierto para escritura"
+ #define ERR_FILE_ALREADY_OPEN_R  "Fichero ya abierto para lectura"
+ #define ERR_INVALID_REFNUM       "El nmero de referencia no es vlido"
+ #define ERR_GETTING_FILE_POS     "Error al tomar la posicin del fichero"
+ #define ERR_VOLUME_OFFLINE       "El volumen est desconectado"
+ #define ERR_PERMISSION_DENIED    "Permiso denegado"
+ #define ERR_VOL_ALREADY_ONLINE   "El volumen ya estaba conectado"
+ #define ERR_NO_SUCH_DRIVE        "No existe tal unidad"
+ #define ERR_NOT_MAC_DISK         "No es un disco Macintosh"
+ #define ERR_VOL_EXTERNAL_FS      "El volumen pertence a un sistema de ficheros externo"
+ #define ERR_PROBLEM_RENAME       "Problemas al renombrar"
+ #define ERR_BAD_MASTER_BLOCK     "Bloque maestro de directorios incorrecto"
+ #define ERR_CANT_MOVE_FORBIDDEN  "Intento de mover forbidden"
+ #define ERR_WRONG_VOL_TYPE       "Tipo de volumen incorrecto"
+ #define ERR_SERVER_VOL_LOST      "El servidor de volmenes ha sido desconectado"
+ #define ERR_FILE_ID_NOT_FOUND    "Identificador de archivo no encontrado"
+ #define ERR_FILE_ID_EXISTS       "El identificador de archivo ya existe"
+ #define ERR_SERVER_NO_RESPOND    "El servidor no responde"
+ #define ERR_USER_AUTH_FAILED     "Fallo al autentificar el usuario"
+ #define ERR_PWORD_EXPIRED        "La Password  en el servidor ha caducado"
+ #define ERR_ACCESS_DENIED        "Acceso denegado"
+ #define ERR_NOT_A_DOS_DISK       "No es un disco de DOS"
+ #define ERR_SHARING_VIOLATION    "Violacin al compartir"
+ #define ERR_CANNOT_MAKE          "No puedo hacer make"
+ #define ERR_DEV_IN_USE           "El dispositivo ya estaba en uso"
+ #define ERR_OPEN_FAILED          "Fallo al abrir"
+ #define ERR_PIPE_BUSY            "Tubera ocupada"
+ #define ERR_SHARING_BUF_EXCEEDED "Buffer de comparticin sobrepasado"
+ #define ERR_TOO_MANY_HANDLES     "Demasiados manejadores (handles)"
+ #define ERR_SEEK_ERROR           "Error de bsqueda"
+ #define ERR_DEL_CWD              "Intentando borrar el directorio de trabajo actual"
+ #define ERR_WRITE_PROTECT_ERROR  "Error de proteccin contra escritura"
+ #define ERR_WRITE_FAULT          "Fallo al escribir"
+ #define ERR_LOCK_VIOLATION       "Violacin del bloqueo"
+ #define ERR_GEN_FAILURE          "Fallo general"
+ #define ERR_UNCERTAIN_MEDIA      "Medio incierto"
+ #define ERR_PROT_VIOLATION       "Violacin de la proteccin"
+ #define ERR_BROKEN_PIPE          "Tubera rota"
+
 #else
  #error Please define PHYSFS_LANG.
 #endif
@@ -1313,6 +1516,11 @@ PHYSFS_uint64 __PHYSFS_platformGetThreadID(void);
  */
 int __PHYSFS_platformStricmp(const char *str1, const char *str2);
 
+/*
+ * This is a pass-through to whatever strnicmp() is called on your platform.
+ */
+int __PHYSFS_platformStrnicmp(const char *s1, const char *s2, PHYSFS_uint32 l);
+
 /*
  * Return non-zero if filename (in platform-dependent notation) exists.
  *  Symlinks should NOT be followed; at this stage, we do not care what the
